@@ -6,7 +6,7 @@ A Python SDK for interacting with CodeMie API.
 
 Basic usage:
 
-    >>> from src.codemie_sdk import CodeMieClient
+    >>> from codemie_sdk import CodeMieClient
     >>> client = CodeMieClient(
     ...     auth_server_url="https://auth.example.com",
     ...     auth_client_id="client_id",
@@ -19,5 +19,5 @@ Basic usage:
 
 from .client.client import CodeMieClient
 
-__version__ = "0.1.19"
+__version__ = "0.1.20"
 __all__ = ["CodeMieClient"]
