@@ -3,9 +3,9 @@
 import uuid
 from datetime import datetime
 from enum import Enum
-from typing import List, Optional, Any, Union
+from typing import List, Optional, Any, Union, Dict
 
-from pydantic import BaseModel, Field, ConfigDict
+from pydantic import BaseModel, Field, ConfigDict, model_validator
 
 from .common import User
 from .integration import Integration
@@ -41,6 +41,7 @@ class ContextType(str, Enum):
 
     KNOWLEDGE_BASE = "knowledge_base"
     CODE = "code"
+    PROVIDER = "provider"
 
 
 class Context(BaseModel):
@@ -89,6 +90,9 @@ class SystemPromptHistory(BaseModel):
 class AssistantBase(BaseModel):
     """Base model for assistant with common fields."""
 
+    def __getitem__(self, key):
+        return getattr(self, key)
+
     model_config = ConfigDict(extra="ignore")
 
     id: Optional[str] = None
@@ -127,6 +131,9 @@ class Assistant(AssistantBase):
 class AssistantRequestBase(AssistantBase):
     """Base model for assistant requests with common request fields."""
 
+    def __getitem__(self, key):
+        return getattr(self, key)
+
     model_config = ConfigDict(extra="ignore", use_enum_values=True)
 
     system_prompt: str
@@ -171,11 +178,33 @@ class ChatMessage(BaseModel):
     message: Optional[str] = Field(default="")
 
 
+class ToolConfig(BaseModel):
+    name: str
+    tool_creds: Optional[Dict[str, Any]] = None
+    integration_id: Optional[str] = None
+
+    @model_validator(mode="after")
+    def validate_credentials_provided(self) -> "ToolConfig":
+        """
+        Validate that either tool_creds or integration_id is provided.
+
+        At least one of these fields must be specified for the tool configuration
+        to be valid. This ensures that the tool has a way to obtain credentials.
+        """
+        if not self.tool_creds and not self.integration_id:
+            raise ValueError("Either tool_creds or integration_id must be provided")
+        if self.tool_creds and self.integration_id:
+            raise ValueError(
+                "Either tool_creds or integration_id must be provided, but not both"
+            )
+        return self
+
+
 class AssistantChatRequest(BaseModel):
     """Model for chat request to assistant."""
 
     conversation_id: Optional[str] = Field(
-        default=str(uuid.uuid4()), description="Conversation identifier"
+        default_factory=lambda: str(uuid.uuid4()), description="Conversation identifier"
     )
     text: str = Field(description="User's input")
     content_raw: Optional[str] = Field(default="", description="Raw content input")
@@ -188,7 +217,7 @@ class AssistantChatRequest(BaseModel):
         description="Conversation history as list of messages or string",
     )
     history_index: int = Field(
-        default=0, description="DataSource in conversation history"
+        default=None, description="DataSource in conversation history"
     )
     stream: bool = Field(default=False, description="Enable streaming response")
     top_k: int = Field(default=10, description="Top K results to consider")
@@ -197,6 +226,7 @@ class AssistantChatRequest(BaseModel):
     metadata: Optional[dict[str, Any]] = Field(
         default=None, description="Provide additional metadata"
     )
+    tools_config: Optional[List[ToolConfig]] = None
 
 
 class BaseModelResponse(BaseModel):
@@ -221,3 +251,15 @@ class BaseModelResponse(BaseModel):
         populate_by_name = True
         # Preserve alias on export
         alias_generator = None
+
+
+class EnvVars(BaseModel):
+    azure_openai_url: Optional[str] = None
+    azure_openai_api_key: Optional[str] = None
+    openai_api_type: Optional[str] = None
+    openai_api_version: Optional[str] = None
+    models_env: Optional[str] = None
+
+
+class ExportAssistantPayload(BaseModel):
+    env_vars: Optional[EnvVars] = None
